@@ -137,6 +137,15 @@ class CommonArgs:
             choices=sorted(targets),
             help="Target to use (default: %(default)s)",
         )
+        self.launcher_grp.add_argument(
+            "--post-launch-delay",
+            type=int,
+            default=0,
+            help="Delay after launching browser before continuing. "
+            "This provides an opportunity to connect debuggers. "
+            ">0 - delay in seconds; 0 - continue immediately; -1 - skip. "
+            "(default: %(default)s)",
+        )
         self.launcher_grp.add_argument(
             "-p", "--prefs", help="DEPRECATED. prefs.js file to use"
         )
@@ -301,14 +310,17 @@ class CommonArgs:
         if args.time_limit is not None and args.time_limit < 1:
             self.parser.error("--time-limit must be >= 1")
 
-        if args.timeout is not None and args.timeout < 1:
-            self.parser.error("--timeout must be >= 1")
+        if args.timeout is not None and args.timeout < 0:
+            self.parser.error("--timeout must be >= 0")
 
         if args.time_limit and args.timeout and args.timeout < args.time_limit:
             self.parser.error("--timeout must be >= --time-limit")
 
-        if args.tool is not None and not args.fuzzmanager:
-            self.parser.error("--tool requires --fuzzmanager")
+        if args.tool:
+            if not args.fuzzmanager:
+                self.parser.error("--tool requires --fuzzmanager")
+            if len(args.tool.split()) != 1 or args.tool.strip() != args.tool:
+                self.parser.error("--tool cannot contain whitespace")
 
         if args.xvfb:  # pragma: no cover
             args.headless = "xvfb"
