@@ -75,7 +75,7 @@ class Reporter(metaclass=ABCMeta):
         """Submit report containing results.
 
         Args:
-            test_cases (iterable): A collection of testcases, ordered newest to oldest,
+            test_cases (iterable): A collection of testcases, ordered oldest to newest,
                                    the newest being the mostly likely to trigger
                                    the result (crash, assert... etc).
             report (Report): Report to submit.
@@ -85,6 +85,9 @@ class Reporter(metaclass=ABCMeta):
         """
         assert isinstance(report, Report)
         assert report.path is not None
+        assert (
+            not test_cases or test_cases[0].timestamp <= test_cases[-1].timestamp
+        ), "tests must be ordered oldest to newest"
         self._pre_submit(report)
         # output report contents to console
         if self.display_logs:
@@ -106,16 +109,17 @@ class Reporter(metaclass=ABCMeta):
 class FilesystemReporter(Reporter):
     DISK_SPACE_ABORT = 512 * 1024 * 1024  # 512 MB
 
-    __slots__ = ("major_bucket", "min_space", "report_path")
+    __slots__ = ("major_bucket", "min_space", "report_path", "report_prefix")
 
     def __init__(self, report_path, major_bucket=True):
         super().__init__()
         self.major_bucket = major_bucket
         self.min_space = FilesystemReporter.DISK_SPACE_ABORT
         self.report_path = Path(report_path)
+        self.report_prefix = None
 
     def _pre_submit(self, report):
-        pass
+        self.report_prefix = report.prefix
 
     def _post_submit(self):
         pass
@@ -128,12 +132,12 @@ class FilesystemReporter(Reporter):
             dest = self.report_path
         dest.mkdir(parents=True, exist_ok=True)
         # dump test cases and the contained files to working directory
-        for test_number, test_case in enumerate(test_cases):
-            dump_path = dest / f"{report.prefix}-{test_number}"
+        for test_number, test_case in enumerate(reversed(test_cases)):
+            dump_path = dest / f"{self.report_prefix}-{test_number}"
             dump_path.mkdir(exist_ok=True)
             test_case.dump(dump_path, include_details=True)
         # move logs into bucket directory
-        log_path = dest / f"{report.prefix}_logs"
+        log_path = dest / f"{self.report_prefix}_logs"
         if log_path.is_dir():
             LOG.warning("Report log path exists '%s'", log_path)
         move(report.path, log_path)
@@ -155,7 +159,9 @@ class FailedLaunchReporter(FilesystemReporter):
 
     def _post_submit(self):
         super()._post_submit()
-        LOG.info("Logs can be found here '%s'", self.report_path)
+        LOG.info(
+            "Logs for %r can be found here '%s'", self.report_prefix, self.report_path
+        )
 
 
 class FuzzManagerReporter(Reporter):
@@ -266,7 +272,7 @@ class FuzzManagerReporter(Reporter):
 
         # dump test cases and the contained files to working directory
         test_case_meta = []
-        for test_number, test_case in enumerate(test_cases):
+        for test_number, test_case in enumerate(reversed(test_cases)):
             test_case_meta.append([test_case.adapter_name, test_case.input_fname])
             dump_path = report.path / f"{report.prefix}-{test_number}"
             dump_path.mkdir(exist_ok=True)
