@@ -8,7 +8,7 @@ from collections import defaultdict
 from datetime import timedelta
 from functools import partial
 from itertools import zip_longest
-from logging import DEBUG, INFO, basicConfig
+from logging import DEBUG, INFO, basicConfig, getLogger
 
 try:
     from os import getloadavg
@@ -36,6 +36,8 @@ __all__ = ("StatusReporter",)
 __author__ = "Tyson Smith"
 __credits__ = ["Tyson Smith"]
 
+LOG = getLogger(__name__)
+
 
 class StatusReporter:
     """Read and merge Grizzly status reports, including tracebacks if found.
@@ -162,15 +164,11 @@ class StatusReporter:
             )
             entries.append((label, None))
             # iterations
-            entries.append(
-                ("Iterations", f"{report.iteration} @ {round(report.rate, 2):0.2f}")
-            )
+            entries.append(("Iterations", f"{report.iteration} @ {report.rate:0.2f}"))
             # ignored
             if report.ignored:
                 ignore_pct = report.ignored / report.iteration * 100
-                entries.append(
-                    ("Ignored", f"{report.ignored} @ {round(ignore_pct, 1)}%")
-                )
+                entries.append(("Ignored", f"{report.ignored} @ {ignore_pct:0.1f}%"))
             # results
             if report.results.total:
                 # avoid divide by zero if results are found before first update
@@ -185,7 +183,7 @@ class StatusReporter:
                 entries.append(
                     (
                         "Results",
-                        f"{report.results.total} @ {round(result_pct, 1):0.1f}%{blkd}",
+                        f"{report.results.total} @ {result_pct:0.1f}%{blkd}",
                     )
                 )
             else:
@@ -204,19 +202,22 @@ class StatusReporter:
                     if entry.total > 300:
                         body.append(str(timedelta(seconds=int(entry.total))))
                     else:
-                        body.append(f"{round(entry.total, 3):0.3f}s")
-                    body.append(
-                        f" {round(entry.total / report.runtime * 100, 2):0.2f}%"
-                    )
-                    body.append(f" ({round(avg, 3):0.3f} avg,")
-                    body.append(f" {round(entry.max, 3):0.3f} max,")
-                    body.append(f" {round(entry.min, 3):0.3f} min)")
+                        body.append(f"{entry.total:0.3f}s")
+                    body.append(f" {entry.total / report.runtime * 100:0.2f}%")
+                    body.append(f" ({avg:0.3f} avg,")
+                    body.append(f" {entry.max:0.3f} max,")
+                    body.append(f" {entry.min:0.3f} min)")
                     entries.append((entry.name, "".join(body)))
             entries.append(("", None))
         return self.format_entries(entries)
 
     def summary(
-        self, runtime=True, sysinfo=False, timestamp=False, iters_per_result=100
+        self,
+        rate=True,
+        runtime=True,
+        sysinfo=False,
+        timestamp=False,
+        iters_per_result=100,
     ):
         """Merge and generate a summary from status reports.
 
@@ -242,29 +243,28 @@ class StatusReporter:
             total_iters = sum(iterations)
 
             # Iterations
-            disp = []
-            disp.append(str(total_iters))
+            disp = [str(total_iters)]
             if count > 1:
                 disp.append(f" ({max(iterations)}, {min(iterations)})")
             entries.append(("Iterations", "".join(disp)))
 
             # Rate
-            disp = []
-            disp.append(f"{count} @ {round(sum(rates), 2):0.2f}")
-            if count > 1:
-                disp.append(
-                    f" ({round(max(rates), 2):0.2f}, {round(min(rates), 2):0.2f})"
-                )
-            entries.append(("Rate", "".join(disp)))
+            if rate:
+                disp = [f"{count} @ {sum(rates):0.2f}"]
+                if count > 1:
+                    disp.append(f" ({max(rates):0.2f}, {min(rates):0.2f})")
+                entries.append(("Rate", "".join(disp)))
 
             # Results
             if total_iters:
                 total_results = sum(results)
                 result_pct = total_results / total_iters * 100
-                disp = []
-                disp.append(str(total_results))
+                buckets = set()
+                for report in self.reports:
+                    buckets.update(x.rid for x in report.results)
+                disp = [f"{total_results} ({len(buckets)})"]
                 if total_results:
-                    disp.append(f" @ {round(result_pct, 1):0.1f}%")
+                    disp.append(f" @ {result_pct:0.1f}%")
                 if any(
                     any(
                         report.results.blockers(
@@ -280,9 +280,7 @@ class StatusReporter:
             # Ignored
             if total_ignored:
                 ignore_pct = total_ignored / total_iters * 100
-                entries.append(
-                    ("Ignored", f"{total_ignored} @ {round(ignore_pct, 1):0.1f}%")
-                )
+                entries.append(("Ignored", f"{total_ignored} @ {ignore_pct:0.1f}%"))
 
             # Runtime
             if runtime:
@@ -292,8 +290,7 @@ class StatusReporter:
             # Log size
             log_usage = sum(log_sizes) / 1_048_576
             if log_usage > self.DISPLAY_LIMIT_LOG:
-                disp = []
-                disp.append(f"{log_usage:0.1f}MB")
+                disp = [f"{log_usage:0.1f}MB"]
                 if count > 1:
                     disp.append(
                         f" ({max(log_sizes) / 1_048_576:0.2f}MB, "
@@ -356,12 +353,12 @@ class StatusReporter:
         disp = []
         disp.append(
             f"{cpu_count(logical=True)} ({cpu_count(logical=False)}) @ "
-            f"{round(cpu_percent(interval=StatusReporter.CPU_POLL_INTERVAL))}%"
+            f"{cpu_percent(interval=StatusReporter.CPU_POLL_INTERVAL):0.0f}%"
         )
         if getloadavg is not None:
             disp.append(" (")
             # round the results of getloadavg(), precision varies across platforms
-            disp.append(", ".join(f"{round(x, 1):0.1f}" for x in getloadavg()))
+            disp.append(", ".join(f"{x:0.1f}" for x in getloadavg()))
             disp.append(")")
         entries.append(("CPU & Load", "".join(disp)))
 
@@ -762,6 +759,7 @@ class ReductionStatusReporter(StatusReporter):
 
     def summary(
         self,
+        rate=False,
         runtime=False,
         sysinfo=False,
         timestamp=False,
@@ -769,6 +767,7 @@ class ReductionStatusReporter(StatusReporter):
         """Merge and generate a summary from status reports.
 
         Args:
+            rate (bool): Ignored (compatibility).
             runtime (bool): Ignored (compatibility).
             sysinfo (bool): Include system info (CPU, disk, RAM... etc) in output.
             timestamp (bool): Include time stamp in output.
@@ -850,7 +849,7 @@ def main(args=None):
         log_fmt = "%(levelname).1s %(name)s [%(asctime)s] %(message)s"
     else:
         log_level = INFO
-        log_fmt = "[%(asctime)s] %(message)s"
+        log_fmt = "%(message)s"
     basicConfig(format=log_fmt, datefmt="%Y-%m-%d %H:%M:%S", level=log_level)
 
     modes = {
@@ -916,25 +915,28 @@ def main(args=None):
                 ofp.write(reporter.specific(sysinfo=True, timestamp=True))
             else:
                 ofp.write(
-                    reporter.summary(runtime=True, sysinfo=False, timestamp=False)
+                    reporter.summary(
+                        rate=False, runtime=True, sysinfo=False, timestamp=False
+                    )
                 )
         return 0
 
     if not reporter.reports:
-        print("Grizzly Status - No status reports to display")
+        LOG.info("Grizzly Status - No status reports to display")
         return 0
 
-    print(
-        f"Grizzly Status - {strftime('%Y/%m/%d %X')} - "
-        f"Instance report frequency: {REPORT_RATE}s\n"
+    LOG.info(
+        "Grizzly Status - %s - Instance report frequency: %ds\n",
+        strftime("%Y/%m/%d %X"),
+        REPORT_RATE,
     )
-    print("[Reports]")
-    print(reporter.specific())
+    LOG.info("[Reports]")
+    LOG.info(reporter.specific())
     if reporter.has_results:
-        print("[Result Signatures]")
-        print(reporter.results())
-    print("[Summary]")
-    print(reporter.summary(sysinfo=args.system_report))
+        LOG.info("[Result Signatures]")
+        LOG.info(reporter.results())
+    LOG.info("[Summary]")
+    LOG.info(reporter.summary(rate=args.type == "active", sysinfo=args.system_report))
     return 0
 
 
