@@ -8,6 +8,7 @@ unit tests for grizzly.replay
 from itertools import cycle
 from pathlib import Path
 
+from FTB.Signatures.CrashInfo import CrashSignature
 from pytest import mark, raises
 
 from sapphire import Served
@@ -150,14 +151,12 @@ def test_replay_04(mocker, server, good_sig):
 def test_replay_05(mocker, server):
     """test ReplayManager.run() - error - landing page not requested"""
     target = mocker.Mock(spec_set=Target, binary="bin", closed=True, launch_timeout=30)
-    testcases = [
-        mocker.Mock(spec_set=TestCase, env_vars={}, landing_page="a.html", optional=[])
-    ]
+    tests = [mocker.MagicMock(spec_set=TestCase, landing_page="a.html")]
     # test target unresponsive
     target.check_result.return_value = Result.NONE
     server.serve_path.return_value = (Served.NONE, [])
     with ReplayManager([], server, target, use_harness=False) as replay:
-        assert not replay.run(testcases, 10, repeat=1)
+        assert not replay.run(tests, 10, repeat=1)
         assert replay.status.ignored == 0
         assert replay.status.iteration == 1
         assert replay.status.results.total == 0
@@ -168,7 +167,7 @@ def test_replay_05(mocker, server):
     target.check_result.return_value = Result.FOUND
     target.save_logs = _fake_save_logs
     with ReplayManager([], server, target, use_harness=False) as replay:
-        results = replay.run(testcases, 10, repeat=1)
+        results = replay.run(tests, 10, repeat=1)
         assert replay.status.ignored == 1
         assert replay.status.iteration == 1
         assert replay.status.results.total == 0
@@ -188,15 +187,13 @@ def test_replay_06(mocker, server):
     target.check_result.side_effect = (Result.NONE, Result.FOUND)
     target.monitor.is_healthy.return_value = False
     target.save_logs = _fake_save_logs
-    testcases = [
-        mocker.Mock(spec_set=TestCase, env_vars={}, landing_page="a.html", optional=[])
-    ]
+    tests = [mocker.MagicMock(spec_set=TestCase, landing_page="a.html")]
     server.serve_path.side_effect = (
         (Served.ALL, ["a.html"]),
         (Served.REQUEST, ["x"]),
     )
     with ReplayManager([], server, target, use_harness=True, relaunch=10) as replay:
-        assert replay.run(testcases, 10, repeat=2, post_launch_delay=-1)
+        assert replay.run(tests, 10, repeat=2, post_launch_delay=-1)
         assert replay.status.ignored == 0
         assert replay.status.iteration == 2
         assert replay.status.results.total == 1
@@ -210,9 +207,9 @@ def test_replay_07(mocker, server):
     target = mocker.Mock(spec_set=Target, closed=True, launch_timeout=30)
     target.check_result.return_value = Result.IGNORED
     target.handle_hang.return_value = True
-    testcases = [mocker.MagicMock(spec_set=TestCase, landing_page="a.html")]
+    tests = [mocker.MagicMock(spec_set=TestCase, landing_page="a.html")]
     with ReplayManager([], server, target, use_harness=False) as replay:
-        assert not replay.run(testcases, 10)
+        assert not replay.run(tests, 10)
         assert replay.status.ignored == 1
         assert replay.status.iteration == 1
         assert replay.status.results.total == 0
@@ -225,9 +222,7 @@ def test_replay_08(mocker, server):
     server.serve_path.return_value = (Served.ALL, ["a.html"])
     target = mocker.Mock(spec_set=Target, binary="path/fake_bin", launch_timeout=30)
     target.save_logs = _fake_save_logs
-    testcases = [
-        mocker.Mock(spec_set=TestCase, env_vars={}, landing_page="a.html", optional=[])
-    ]
+    tests = [mocker.MagicMock(spec_set=TestCase, landing_page="a.html")]
     # early failure
     target.check_result.side_effect = (
         Result.FOUND,
@@ -236,7 +231,7 @@ def test_replay_08(mocker, server):
     )
     target.monitor.is_healthy.side_effect = (False, False, True, False)
     with ReplayManager([], server, target, use_harness=False) as replay:
-        assert not replay.run(testcases, 10, repeat=4, min_results=3)
+        assert not replay.run(tests, 10, repeat=4, min_results=3)
         assert target.close.call_count == 4
         assert replay.status.iteration == 3
         assert replay.status.results.total == 1
@@ -250,7 +245,7 @@ def test_replay_08(mocker, server):
     )
     target.monitor.is_healthy.side_effect = (False, False, False)
     with ReplayManager([], server, target, use_harness=False) as replay:
-        results = replay.run(testcases, 10, repeat=4, min_results=2)
+        results = replay.run(tests, 10, repeat=4, min_results=2)
         assert target.close.call_count == 4
         assert replay.status.iteration == 3
         assert replay.status.results.total == 2
@@ -264,7 +259,7 @@ def test_replay_08(mocker, server):
     target.monitor.is_healthy.side_effect = None
     target.monitor.is_healthy.return_value = True
     with ReplayManager([], server, target, use_harness=False) as replay:
-        assert not replay.run(testcases, 10, repeat=4, min_results=4, exit_early=False)
+        assert not replay.run(tests, 10, repeat=4, min_results=4, exit_early=False)
         assert target.close.call_count == 5
         assert replay.status.iteration == 4
         assert replay.status.results.total == 0
@@ -274,7 +269,7 @@ def test_replay_08(mocker, server):
     target.check_result.return_value = Result.FOUND
     target.monitor.is_healthy.return_value = False
     with ReplayManager([], server, target, use_harness=False) as replay:
-        results = replay.run(testcases, 10, repeat=4, min_results=1, exit_early=False)
+        results = replay.run(tests, 10, repeat=4, min_results=1, exit_early=False)
         assert target.close.call_count == 5
         assert replay.status.iteration == 4
         assert replay.status.results.total == 4
@@ -286,17 +281,11 @@ def test_replay_08(mocker, server):
 def test_replay_09(mocker, server):
     """test ReplayManager.run() - test signatures - fail to meet minimum"""
     mocker.patch("grizzly.common.runner.sleep", autospec=True)
-    report_1 = mocker.Mock(
-        spec_set=Report, crash_hash="hash1", major="0123abcd", minor="01239999"
-    )
+    report_1 = mocker.Mock(spec_set=Report, crash_hash="h1", major="0123", minor="0123")
     report_1.crash_info.createShortSignature.return_value = "[@ test1]"
-    report_2 = mocker.Mock(
-        spec_set=Report, crash_hash="hash2", major="0123abcd", minor="abcd9876"
-    )
+    report_2 = mocker.Mock(spec_set=Report, crash_hash="h2", major="0123", minor="abcd")
     report_2.crash_info.createShortSignature.return_value = "[@ test2]"
-    report_3 = mocker.Mock(
-        spec_set=Report, crash_hash="hash2", major="0123abcd", minor="abcd9876"
-    )
+    report_3 = mocker.Mock(spec_set=Report, crash_hash="h2", major="0123", minor="abcd")
     report_3.crash_info.createShortSignature.return_value = "[@ test2]"
     fake_report = mocker.patch("grizzly.replay.replay.Report", autospec=True)
     fake_report.side_effect = (report_1, report_2, report_3)
@@ -306,13 +295,11 @@ def test_replay_09(mocker, server):
     signature.matches.side_effect = (True, False, False)
     target = mocker.Mock(spec_set=Target, binary="fake_bin", launch_timeout=30)
     target.check_result.return_value = Result.FOUND
-    testcases = [
-        mocker.Mock(spec_set=TestCase, env_vars={}, landing_page="a.html", optional=[])
-    ]
+    tests = [mocker.MagicMock(spec_set=TestCase, landing_page="a.html")]
     with ReplayManager(
         [], server, target, signature=signature, use_harness=False
     ) as replay:
-        results = replay.run(testcases, 10, repeat=3, min_results=2)
+        results = replay.run(tests, 10, repeat=3, min_results=2)
         assert target.close.call_count == 4
         assert replay.signature == signature
         assert replay.status.iteration == 3
@@ -330,32 +317,24 @@ def test_replay_09(mocker, server):
 
 def test_replay_10(mocker, server):
     """test ReplayManager.run() - test signatures - multiple matches"""
-    report_0 = mocker.Mock(
-        spec_set=Report, crash_hash="hash1", major="0123abcd", minor="01239999"
-    )
+    report_0 = mocker.Mock(spec_set=Report, crash_hash="h1", major="0123", minor="0123")
     report_0.crash_info.createShortSignature.return_value = "[@ test1]"
-    report_1 = mocker.Mock(
-        spec_set=Report, crash_hash="hash2", major="0123abcd", minor="abcd9876"
-    )
+    report_1 = mocker.Mock(spec_set=Report, crash_hash="h2", major="0123", minor="abcd")
     report_1.crash_info.createShortSignature.return_value = "[@ test2]"
     fake_report = mocker.patch("grizzly.replay.replay.Report", autospec=True)
     fake_report.side_effect = (report_0, report_1)
     fake_report.calc_hash.return_value = "bucketHASH"
     server.serve_path.return_value = (Served.ALL, ["a.html"])
-    signature = mocker.Mock()
-    signature.matches.side_effect = (True, True)
+    sig = mocker.Mock(spec_set=CrashSignature)
+    sig.matches.side_effect = (True, True)
     target = mocker.Mock(spec_set=Target, binary="fake_bin", launch_timeout=30)
     target.check_result.return_value = Result.FOUND
     target.monitor.is_healthy.return_value = False
-    testcases = [
-        mocker.Mock(spec_set=TestCase, env_vars={}, landing_page="a.html", optional=[])
-    ]
-    with ReplayManager(
-        [], server, target, signature=signature, use_harness=False
-    ) as replay:
-        results = replay.run(testcases, 10, repeat=2, min_results=2)
+    tests = [mocker.MagicMock(spec_set=TestCase, landing_page="a.html")]
+    with ReplayManager([], server, target, signature=sig, use_harness=False) as replay:
+        results = replay.run(tests, 10, repeat=2, min_results=2)
         assert target.close.call_count == 3
-        assert replay.signature == signature
+        assert replay.signature == sig
         assert replay.status.iteration == 2
         assert replay.status.results.total == 2
         assert replay.status.ignored == 0
@@ -365,18 +344,14 @@ def test_replay_10(mocker, server):
     assert results[0].count == 2
     assert report_0.cleanup.call_count == 0
     assert report_1.cleanup.call_count == 1
-    assert signature.matches.call_count == 2
+    assert sig.matches.call_count == 2
 
 
 def test_replay_11(mocker, server):
     """test ReplayManager.run() - any crash - success"""
-    report_1 = mocker.Mock(
-        spec_set=Report, crash_hash="hash1", major="0123abcd", minor="01239999"
-    )
+    report_1 = mocker.Mock(spec_set=Report, crash_hash="h1", major="0123", minor="0123")
     report_1.crash_info.createShortSignature.return_value = "[@ test1]"
-    report_2 = mocker.Mock(
-        spec_set=Report, crash_hash="hash2", major="0123abcd", minor="abcd9876"
-    )
+    report_2 = mocker.Mock(spec_set=Report, crash_hash="h2", major="0123", minor="abcd")
     report_2.crash_info.createShortSignature.return_value = "[@ test2]"
     fake_report = mocker.patch("grizzly.replay.replay.Report", autospec=True)
     fake_report.side_effect = (report_1, report_2)
@@ -384,11 +359,9 @@ def test_replay_11(mocker, server):
     target = mocker.Mock(spec_set=Target, binary="fake_bin", launch_timeout=30)
     target.check_result.return_value = Result.FOUND
     target.monitor.is_healthy.return_value = False
-    testcases = [
-        mocker.Mock(spec_set=TestCase, env_vars={}, landing_page="a.html", optional=[])
-    ]
+    tests = [mocker.MagicMock(spec_set=TestCase, landing_page="a.html")]
     with ReplayManager([], server, target, any_crash=True, use_harness=False) as replay:
-        results = replay.run(testcases, 10, repeat=2, min_results=2)
+        results = replay.run(tests, 10, repeat=2, min_results=2)
         assert target.close.call_count == 3
         assert replay.signature is None
         assert replay.status.iteration == 2
@@ -404,13 +377,9 @@ def test_replay_11(mocker, server):
 
 def test_replay_12(mocker, server):
     """test ReplayManager.run() - any crash - fail to meet minimum"""
-    report_1 = mocker.Mock(
-        spec_set=Report, crash_hash="hash1", major="0123abcd", minor="01239999"
-    )
+    report_1 = mocker.Mock(spec_set=Report, crash_hash="h1", major="0123", minor="0123")
     report_1.crash_info.createShortSignature.return_value = "[@ test1]"
-    report_2 = mocker.Mock(
-        spec_set=Report, crash_hash="hash2", major="0123abcd", minor="abcd9876"
-    )
+    report_2 = mocker.Mock(spec_set=Report, crash_hash="h2", major="0123", minor="abcd")
     report_2.crash_info.createShortSignature.return_value = "[@ test2]"
     fake_report = mocker.patch("grizzly.replay.replay.Report", autospec=True)
     fake_report.side_effect = (report_1, report_2)
@@ -423,11 +392,9 @@ def test_replay_12(mocker, server):
         Result.NONE,
     )
     target.monitor.is_healthy.return_value = False
-    testcases = [
-        mocker.Mock(spec_set=TestCase, env_vars={}, landing_page="a.html", optional=[])
-    ]
+    tests = [mocker.MagicMock(spec_set=TestCase, landing_page="a.html")]
     with ReplayManager([], server, target, any_crash=True) as replay:
-        assert not replay.run(testcases, 10, repeat=4, min_results=3)
+        assert not replay.run(tests, 10, repeat=4, min_results=3)
         assert target.close.call_count == 5
         assert replay.signature is None
         assert replay.status.iteration == 4
@@ -445,11 +412,9 @@ def test_replay_13(mocker, server):
     target.check_result.return_value = Result.FOUND
     target.save_logs = _fake_save_logs
     target.monitor.is_healthy.return_value = False
-    testcases = [
-        mocker.Mock(spec_set=TestCase, env_vars={}, landing_page="a.html", optional=[])
-    ]
+    tests = [mocker.MagicMock(spec_set=TestCase, landing_page="a.html")]
     with ReplayManager([], server, target, any_crash=True, use_harness=False) as replay:
-        results = replay.run(testcases, 10, repeat=1, min_results=1)
+        results = replay.run(tests, 10, repeat=1, min_results=1)
         assert results
         assert not any(x.expected for x in results)
         assert target.close.call_count == 2
@@ -460,32 +425,28 @@ def test_replay_13(mocker, server):
 
 def test_replay_14(mocker, server):
     """test ReplayManager.run() - no signature - use first crash"""
-    report_1 = mocker.Mock(
-        spec_set=Report, crash_hash="hash1", major="0123", minor="9999"
-    )
-    report_1.crash_info.createShortSignature.return_value = "[@ test1]"
-    auto_sig = mocker.Mock()
+    auto_sig = mocker.Mock(spec_set=CrashSignature)
     auto_sig.matches.side_effect = (True, False, True)
+    # original
+    report_1 = mocker.Mock(spec_set=Report, crash_hash="h1", major="012", minor="999")
+    report_1.crash_info.createShortSignature.return_value = "[@ test1]"
     report_1.crash_signature = auto_sig
-    report_2 = mocker.Mock(
-        spec_set=Report, crash_hash="hash2", major="abcd", minor="9876"
-    )
+    # non matching report
+    report_2 = mocker.Mock(spec_set=Report, crash_hash="h2", major="abc", minor="987")
     report_2.crash_info.createShortSignature.return_value = "[@ test2]"
-    report_3 = mocker.Mock(
-        spec_set=Report, crash_hash="hash1", major="0123", minor="9999"
-    )
+    # matching report
+    report_3 = mocker.Mock(spec_set=Report, crash_hash="h1", major="012", minor="999")
     report_3.crash_info.createShortSignature.return_value = "[@ test1]"
     fake_report = mocker.patch("grizzly.replay.replay.Report", autospec=True)
     fake_report.side_effect = (report_1, report_2, report_3)
+    fake_report.calc_hash.return_value = "bucket_hash"
     server.serve_path.return_value = (Served.ALL, ["a.html"])
     target = mocker.Mock(spec_set=Target, binary="fake_bin", launch_timeout=30)
     target.check_result.return_value = Result.FOUND
     target.monitor.is_healthy.return_value = False
-    testcases = [
-        mocker.Mock(spec_set=TestCase, env_vars={}, landing_page="a.html", optional=[])
-    ]
+    tests = [mocker.MagicMock(spec_set=TestCase, landing_page="a.html")]
     with ReplayManager([], server, target, use_harness=False) as replay:
-        results = replay.run(testcases, 10, repeat=3, min_results=2)
+        results = replay.run(tests, 10, repeat=3, min_results=2)
         assert target.close.call_count == 4
         assert replay.signature == auto_sig
         assert replay.status.iteration == 3
@@ -502,23 +463,19 @@ def test_replay_14(mocker, server):
 
 def test_replay_15(mocker, server):
     """test ReplayManager.run() - unexpected exception"""
-    report_0 = mocker.Mock(
-        spec_set=Report, crash_hash="hash1", major="0123abcd", minor="01239999"
-    )
+    report_0 = mocker.Mock(spec_set=Report, crash_hash="h1", major="0123", minor="0123")
     report_0.crash_info.createShortSignature.return_value = "[@ test1]"
     fake_report = mocker.patch("grizzly.replay.replay.Report", autospec=True)
     fake_report.side_effect = (report_0,)
     server.serve_path.side_effect = ((Served.ALL, ["a.html"]), KeyboardInterrupt)
     target = mocker.Mock(spec_set=Target, binary="fake_bin", launch_timeout=30)
     target.check_result.return_value = Result.FOUND
-    testcases = [
-        mocker.Mock(spec_set=TestCase, env_vars={}, landing_page="a.html", optional=[])
-    ]
+    tests = [mocker.MagicMock(spec_set=TestCase, landing_page="a.html")]
     with ReplayManager(
         [], server, target, any_crash=True, use_harness=True, relaunch=2
     ) as replay:
         with raises(KeyboardInterrupt):
-            replay.run(testcases, 10, repeat=3, min_results=2, post_launch_delay=-1)
+            replay.run(tests, 10, repeat=3, min_results=2, post_launch_delay=-1)
         assert replay.signature is None
         assert replay.status.iteration == 2
         assert replay.status.results.total == 1
@@ -535,12 +492,11 @@ def test_replay_16(mocker, server):
     server.serve_path.return_value = (Served.ALL, ["a.html"])
     target = mocker.Mock(spec_set=Target, closed=True, launch_timeout=30)
     target.check_result.return_value = Result.NONE
-    testcases = [
-        mocker.Mock(spec_set=TestCase, env_vars={}, landing_page="a.html", optional=[])
-        for _ in range(3)
+    tests = [
+        mocker.MagicMock(spec_set=TestCase, landing_page="a.html") for _ in range(3)
     ]
     with ReplayManager([], server, target, use_harness=True) as replay:
-        assert not replay.run(testcases, 10)
+        assert not replay.run(tests, 10)
         assert replay.status.ignored == 0
         assert replay.status.iteration == 1
         assert replay.status.results.total == 0
@@ -555,12 +511,11 @@ def test_replay_17(mocker, server):
     type(target).closed = mocker.PropertyMock(side_effect=cycle([True, False]))
     target.check_result.return_value = Result.NONE
     target.monitor.is_healthy.return_value = False
-    testcases = [
-        mocker.Mock(spec_set=TestCase, env_vars={}, landing_page="a.html", optional=[])
-        for _ in range(3)
+    tests = [
+        mocker.MagicMock(spec_set=TestCase, landing_page="a.html") for _ in range(3)
     ]
     with ReplayManager([], server, target, use_harness=True, relaunch=2) as replay:
-        assert not replay.run(testcases, 10, repeat=10, post_launch_delay=-1)
+        assert not replay.run(tests, 10, repeat=10, post_launch_delay=-1)
         assert server.serve_path.call_count == 30
         assert target.close.call_count == 6
         assert target.launch.call_count == 5
@@ -573,9 +528,9 @@ def test_replay_17(mocker, server):
 def test_replay_18(mocker, server):
     """test ReplayManager.run() - multiple TestCases - successful repro"""
     server.serve_path.side_effect = (
-        (Served.ALL, ["a.html"]),
-        (Served.ALL, ["b.html"]),
-        (Served.ALL, ["c.html"]),
+        (Served.ALL, ["0.html"]),
+        (Served.ALL, ["1.html"]),
+        (Served.ALL, ["2.html"]),
     )
     target = mocker.Mock(spec_set=Target, binary="fake_bin", launch_timeout=30)
     target.check_result.side_effect = (
@@ -585,23 +540,21 @@ def test_replay_18(mocker, server):
     )
     target.monitor.is_healthy.return_value = False
     target.save_logs = _fake_save_logs
-    testcases = [
-        mocker.Mock(spec_set=TestCase, env_vars={}, landing_page="a.html", optional=[]),
-        mocker.Mock(spec_set=TestCase, env_vars={}, landing_page="b.html", optional=[]),
-        mocker.Mock(spec_set=TestCase, env_vars={}, landing_page="c.html", optional=[]),
+    tests = [
+        mocker.MagicMock(spec_set=TestCase, landing_page=f"{i}.html") for i in range(3)
     ]
     with ReplayManager([], server, target, use_harness=True) as replay:
-        results = replay.run(testcases, 30, post_launch_delay=-1)
+        results = replay.run(tests, 30, post_launch_delay=-1)
         assert target.close.call_count == 2
         assert replay.status.ignored == 0
         assert replay.status.iteration == 1
         assert replay.status.results.total == 1
     assert len(results) == 1
-    assert len(results[0].served) == len(testcases)
-    assert results[0].served[0][0] == "a.html"
-    assert results[0].served[1][0] == "b.html"
-    assert results[0].served[2][0] == "c.html"
-    assert len(results[0].durations) == len(testcases)
+    assert len(results[0].served) == len(tests)
+    assert results[0].served[0][0] == "0.html"
+    assert results[0].served[1][0] == "1.html"
+    assert results[0].served[2][0] == "2.html"
+    assert len(results[0].durations) == len(tests)
 
 
 def test_replay_19(mocker, server):
@@ -648,7 +601,7 @@ def test_replay_20(mocker, tmp_path):
     result2.report = mocker.Mock(
         spec_set=Report, path=tmp_path / "report_other2", prefix="other2"
     )
-    test = mocker.Mock(spec_set=TestCase)
+    test = mocker.Mock(spec_set=TestCase, timestamp=1.0)
     path = tmp_path / "dest"
     ReplayManager.report_to_filesystem(path, [result0, result1, result2], tests=[test])
     assert test.dump.call_count == 3  # called once per report
@@ -696,12 +649,7 @@ def test_replay_21(mocker, tmp_path):
     assert assets is None
     # success select
     test0.pop_assets.return_value = mocker.Mock(spec_set=AssetManager)
-    fake_load.return_value = [
-        test0,
-        test1,
-        test2,
-        mocker.Mock(spec_set=TestCase, env_vars={}),
-    ]
+    fake_load.return_value = [test0, test1, test2, mocker.MagicMock(spec_set=TestCase)]
     tests, assets, _ = ReplayManager.load_testcases(str(tmp_path), subset=[1, 3])
     assert len(tests) == 2
     assert tests[0].landing_page == "x.html"
@@ -811,3 +759,120 @@ def test_replay_23(mocker):
     ReplayManager.report_to_fuzzmanager(results, [], tool="test-override")
     assert reporter.call_args == (("test-override",),)
     assert reporter.return_value.submit.call_count == 2
+
+
+def test_replay_24(mocker, server, tmp_path):
+    """test ReplayManager.run() - signature - matching stacks"""
+    sig_file = tmp_path / "sig.json"
+    sig_file.write_text(
+        "{\n"
+        '  "symptoms": [\n'
+        "    {\n"
+        '      "src": "stderr",\n'
+        '      "type": "output",\n'
+        '      "value": "/STDERR/"\n'
+        "    }\n"
+        "  ]\n"
+        "}\n"
+    )
+    sig = CrashSignature.fromFile(str(sig_file))
+
+    server.serve_path.return_value = (Served.ALL, ["index.html"])
+    target = mocker.MagicMock(spec_set=Target, binary="fake_bin", launch_timeout=30)
+    target.check_result.return_value = Result.FOUND
+    target.monitor.is_healthy.return_value = False
+
+    call_count = 0
+
+    def _save_logs_variation(result_logs, _meta=False):
+        """create different stacks each call"""
+        nonlocal call_count
+        call_count += 1
+        log_path = Path(result_logs)
+        (log_path / "log_stderr.txt").write_text("STDERR log\n")
+        (log_path / "log_stdout.txt").write_text("STDOUT log\n")
+        with (log_path / "log_asan_blah.txt").open("w") as log_fp:
+            log_fp.write("==1==ERROR: AddressSanitizer: ")
+            log_fp.write("SEGV on unknown address 0x0 (pc 0x0 bp 0x0 sp 0x0 T0)\n")
+            log_fp.write(f"    #0 0xbad000 in call_a{call_count:02d} file.c:23:34\n")
+            log_fp.write(f"    #1 0xbad001 in call_b{call_count:02d} file.c:12:45\n")
+
+    target.save_logs.side_effect = _save_logs_variation
+
+    with TestCase("index.html", "redirect.html", "test-adapter") as testcase:
+        with ReplayManager([], server, target, relaunch=10, signature=sig) as replay:
+            results = replay.run([testcase], 10, min_results=2, repeat=2)
+            assert replay.signature is not None
+            assert replay.status.ignored == 0
+            assert replay.status.iteration == 2
+            assert replay.status.results.total == 2
+        assert len(results) == 1
+        assert results[0].count == 2
+        assert results[0].expected
+        assert results[0].report
+        results[0].report.cleanup()
+
+
+@mark.parametrize(
+    "stderr_log, ignored, total, include_stack",
+    [
+        # match stack only
+        (["STDERR log\n", "STDERR log\n"], 0, 2, [True] * 2),
+        # match stack only
+        (["STDERR log\n", "STDERR log\nAssertion failure: test\n"], 0, 2, [True] * 2),
+        # match stack and assertion message
+        (["STDERR log\nAssertion failure: test\n", "STDERR log\n"], 1, 1, [True] * 2),
+        # match stack and assertion message
+        (["Assertion failure: 1\n", "Assertion failure: 2\n"], 1, 1, [True] * 2),
+        # match, no match, match
+        (["Assertion failure: 1\n", "a\n", "Assertion failure: 1\n"], 1, 2, [True] * 3),
+        # fail to create signature x2 (missing stack)
+        (["STDERR log\n", "STDERR log\n"], 0, 2, [False] * 2),
+        # fail to create signature, create signature
+        (["STDERR log\n", "STDERR log\n"], 1, 1, [False, True]),
+        # create signature, fail to create signature
+        (["STDERR log\n", "STDERR log\n"], 1, 1, [True, False]),
+    ],
+)
+def test_replay_25(mocker, server, stderr_log, ignored, total, include_stack):
+    """test ReplayManager.run() - no signature - match first result"""
+    # NOTE: this is similar to "no signature - use first crash" test
+    # but this is more of an integration test
+    iters = len(stderr_log)
+    assert iters == ignored + total, "test is broken"
+    assert iters == len(include_stack), "test is broken"
+    server.serve_path.return_value = (Served.ALL, ["index.html"])
+    target = mocker.Mock(spec_set=Target, binary="fake_bin", launch_timeout=30)
+    target.check_result.return_value = Result.FOUND
+    target.monitor.is_healthy.return_value = False
+
+    def _save_logs_variation(result_logs, _meta=False):
+        """create logs"""
+        nonlocal stderr_log
+        nonlocal include_stack
+        log_path = Path(result_logs)
+        (log_path / "log_stderr.txt").write_text(stderr_log.pop(0))
+        (log_path / "log_stdout.txt").write_text("STDOUT log\n")
+        if include_stack.pop(0):
+            with (log_path / "log_asan_blah.txt").open("w") as log_fp:
+                log_fp.write("==1==ERROR: AddressSanitizer: ")
+                log_fp.write("SEGV on unknown address 0x0 (pc 0x0 bp 0x0 sp 0x0 T0)\n")
+                log_fp.write("    #0 0xbad000 in call_a file.c:23:34\n")
+                log_fp.write("    #1 0xbad001 in call_b file.c:12:45\n")
+
+    target.save_logs.side_effect = _save_logs_variation
+
+    has_sig = include_stack[0]
+    with TestCase("index.html", "redirect.html", "test-adapter") as testcase:
+        with ReplayManager([], server, target, relaunch=10) as replay:
+            results = replay.run([testcase], 10, min_results=2, repeat=iters)
+            if has_sig:
+                assert replay.signature is not None
+            else:
+                assert replay.signature is None
+            assert replay.status.ignored == ignored
+            assert replay.status.iteration == iters
+            assert replay.status.results.total == total
+        for result in results:
+            result.report.cleanup()
+        assert results
