@@ -1,4 +1,3 @@
-# coding=utf-8
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
@@ -22,6 +21,7 @@ def parse_args(argv=None):
     parser.add_argument(
         "-b",
         "--byte-order",
+        choices=Loki.BYTE_ORDERS,
         default=None,
         help="Byte order to use when mutating multiple bytes at once. "
         "Use '>' for big-endian or '<' for little-endian (default: random)",
@@ -48,7 +48,4 @@ def parse_args(argv=None):
     )
     args = parser.parse_args(argv)
 
-    if args.byte_order and args.byte_order not in Loki.BYTE_ORDERS:
-        parser.error("Invalid byte order %r" % (args.byte_order,))
-
     return args
