@@ -81,72 +81,66 @@ class ConnectionManager:
         # it is important to keep this loop fast because it can limit
         # the total iteration rate of Grizzly
         while not self._job.is_complete(wait=poll):
-            # check for a timeout
-            if deadline and deadline <= time():
-                return False
             # check if callback returns False
             if continue_cb is not None and not continue_cb():
                 LOG.debug("continue_cb() returned False")
                 break
+            # check for a timeout
+            if deadline and deadline <= time():
+                return False
         return True
 
     @staticmethod
     def listener(serv_sock, serv_job, max_workers, shutdown_delay=0):
         assert max_workers > 0
         assert shutdown_delay >= 0
-        total_launches = 0
-        worker_pool = []
-        pool_size = 0
-        LOG.debug("starting listener")
+        launches = 0
+        workers = []
+        start_time = time()
+        LOG.debug("starting listener (max workers %d)", max_workers)
         try:
             while not serv_job.is_complete():
                 if not serv_job.accepting.wait(0.05):
                     continue
                 worker = Worker.launch(serv_sock, serv_job)
                 if worker is not None:
-                    worker_pool.append(worker)
-                    pool_size += 1
-                    total_launches += 1
-                # manage worker pool
-                if pool_size >= max_workers:
-                    LOG.debug(
-                        "pool size: %d, waiting for worker to finish...", pool_size
-                    )
-                    serv_job.worker_complete.wait()
+                    workers.append(worker)
+                    launches += 1
+                # manage workers
+                if len(workers) >= max_workers:
+                    LOG.debug("max worker limit (%d) hit, waiting...", len(workers))
+                    assert serv_job.worker_complete.wait(300)
                     serv_job.worker_complete.clear()
-                    LOG.debug("removing completed workers from worker pool")
+                    LOG.debug("removing completed workers...")
                     # sometimes the thread that triggered the event doesn't quite
                     # cleanup in time, so retry (10x with 0.5 second sleep on failure)
                     for _ in range(10):
-                        worker_pool = list(w for w in worker_pool if not w.done)
-                        pool_size = len(worker_pool)
-                        if pool_size < max_workers:
+                        workers = list(w for w in workers if not w.done)
+                        if len(workers) < max_workers:
                             break
                         sleep(0.5)  # pragma: no cover
                     else:  # pragma: no cover
                         # this should never happen
-                        raise RuntimeError("Failed to trim worker pool!")
-                    LOG.debug("trimmed worker pool (size: %d)", pool_size)
+                        raise RuntimeError("Failed remove workers!")
+                    LOG.debug("removed completed workers (%d active)", len(workers))
         except Exception:  # pylint: disable=broad-except
             if serv_job.exceptions.empty():
                 serv_job.exceptions.put(exc_info())
             serv_job.finish()
         finally:
-            LOG.debug(
-                "shutting down listener, waiting %0.2fs for %d of %d worker(s)...",
-                shutdown_delay,
-                len(worker_pool),
-                total_launches,
-            )
+            LOG.debug("%d requests in %0.3f seconds", launches, time() - start_time)
+            LOG.debug("shutting down, waiting for %d worker(s)...", len(workers))
             # use shutdown_delay to avoid cutting off connections
             deadline = time() + shutdown_delay
+            # wait for all running workers to exit
             while time() < deadline:
-                # wait for all running workers to exit
-                if all(w.done for w in worker_pool):
+                serv_job.worker_complete.clear()
+                if all(w.done for w in workers):
                     break
-                sleep(0.1)
+                serv_job.worker_complete.wait(max(deadline - time(), 0))
             else:  # pragma: no cover
-                worker_pool = list(w for w in worker_pool if not w.done)
-                LOG.debug("closing remaining %d worker(s)", len(worker_pool))
-                for worker in worker_pool:
+                # reached deadline force close workers
+                workers = list(w for w in workers if not w.done)
+                LOG.debug("closing remaining %d worker(s)", len(workers))
+                for worker in workers:
                     worker.close()
