@@ -89,7 +89,7 @@ def test_connection_manager_04(mocker, tmp_path):
     fake_time = mocker.patch("sapphire.connection_manager.time", autospec=True)
     fake_time.side_effect = count()
     with ConnectionManager(job, serv_sock, max_workers=10) as loadmgr:
-        assert not loadmgr.wait(1, continue_cb=lambda: False, poll=0.01)
+        assert not loadmgr.wait(1, continue_cb=lambda: True, poll=0.01)
 
 
 def test_connection_manager_05(mocker, tmp_path):
