@@ -6,10 +6,10 @@ Sapphire unit tests
 import socket
 import threading
 
-import pytest
+from pytest import mark, raises
 
 from .job import Job
-from .worker import Worker, WorkerError
+from .worker import Request, Worker, WorkerError
 
 
 def test_worker_01(mocker):
@@ -41,36 +41,58 @@ def test_worker_02(mocker):
     )
     # it is assumed that launch() has already been called at this point
     worker._thread.is_alive.return_value = True
-    with pytest.raises(WorkerError, match="Worker thread failed to join!"):
+    with raises(WorkerError, match="Worker thread failed to join!"):
         worker.close()
 
 
-def test_worker_03(mocker):
-    """test Worker.launch() fail cases"""
+@mark.parametrize(
+    "exc",
+    [
+        socket.timeout("test"),
+        OSError("test"),
+    ],
+)
+def test_worker_03(mocker, exc):
+    """test Worker.launch() socket exception cases"""
+    mocker.patch("sapphire.worker.Thread", autospec=True)
     serv_con = mocker.Mock(spec_set=socket.socket)
     serv_job = mocker.Mock(spec_set=Job)
-    fake_thread = mocker.patch("sapphire.worker.Thread", autospec=True)
-    mocker.patch("sapphire.worker.sleep", autospec=True)
-
-    serv_con.accept.side_effect = socket.timeout
+    serv_con.accept.side_effect = exc
     assert Worker.launch(serv_con, serv_job) is None
+    assert serv_job.accepting.clear.call_count == 0
+    assert serv_job.accepting.set.call_count == 0
 
-    serv_con.accept.side_effect = None
+
+def test_worker_04(mocker):
+    """test Worker.launch() thread exception case"""
+    mocker.patch("sapphire.worker.sleep", autospec=True)
+    mocker.patch("sapphire.worker.Thread", side_effect=threading.ThreadError("test"))
+    serv_con = mocker.Mock(spec_set=socket.socket)
+    serv_job = mocker.Mock(spec_set=Job)
     conn = mocker.Mock(spec_set=socket.socket)
     serv_con.accept.return_value = (conn, None)
-    fake_thread.side_effect = threading.ThreadError
     assert Worker.launch(serv_con, serv_job) is None
     assert conn.close.call_count == 1
     assert serv_job.accepting.clear.call_count == 0
     assert serv_job.accepting.set.call_count == 1
 
 
-def test_worker_04(mocker, tmp_path):
+@mark.parametrize(
+    "url",
+    [
+        "/testfile",
+        "/./testfile",
+        "http://localhost/testfile",
+        "http://127.0.0.1/testfile",
+        "http://sub.host:1234/testfile",
+    ],
+)
+def test_worker_05(mocker, tmp_path, url):
     """test Worker.launch()"""
     (tmp_path / "testfile").touch()
     job = Job(tmp_path)
     clnt_sock = mocker.Mock(spec_set=socket.socket)
-    clnt_sock.recv.return_value = b"GET /testfile HTTP/1.1"
+    clnt_sock.recv.return_value = f"GET {url} HTTP/1.1".encode()
     serv_sock = mocker.Mock(spec_set=socket.socket)
     serv_sock.accept.return_value = (clnt_sock, None)
     worker = Worker.launch(serv_sock, job)
@@ -79,15 +101,45 @@ def test_worker_04(mocker, tmp_path):
         assert job.is_complete(wait=1)
     finally:
         worker.close()
+        if not job.exceptions.empty():
+            raise job.exceptions.get()[1]
     assert worker.done
+    assert clnt_sock.sendall.called
     assert serv_sock.accept.call_count == 1
     assert clnt_sock.close.call_count == 2
 
 
-def test_worker_05(mocker):
+@mark.parametrize(
+    "req, response",
+    [
+        (b"a", b"400 Bad Request"),
+        (b"BAD / HTTP/1.1", b"405 Method Not Allowed"),
+    ],
+)
+def test_worker_06(mocker, tmp_path, req, response):
+    """test Worker.launch() with invalid/unsupported requests"""
+    (tmp_path / "testfile").touch()
+    job = Job(tmp_path)
+    clnt_sock = mocker.Mock(spec_set=socket.socket)
+    clnt_sock.recv.return_value = req
+    serv_sock = mocker.Mock(spec_set=socket.socket)
+    serv_sock.accept.return_value = (clnt_sock, None)
+    worker = Worker.launch(serv_sock, job)
+    assert worker is not None
+    worker.join(timeout=1)
+    worker.close()
+    if not job.exceptions.empty():
+        raise job.exceptions.get()[1]
+    assert serv_sock.accept.call_count == 1
+    assert clnt_sock.close.call_count == 2
+    assert clnt_sock.sendall.called
+    assert response in clnt_sock.sendall.call_args[0][0]
+
+
+def test_worker_07(mocker):
     """test Worker.handle_request() socket errors"""
     serv_con = mocker.Mock(spec_set=socket.socket)
-    serv_con.recv.side_effect = socket.error
+    serv_con.recv.side_effect = OSError
     serv_job = mocker.Mock(spec_set=Job)
     Worker.handle_request(serv_con, serv_job)
     assert serv_job.accepting.set.call_count == 1
@@ -122,3 +174,35 @@ def test_response_data_04():
     assert b"Content-Length: " in output
     assert b"HTTP/1.1 404 Not Found" in output
     assert b"window.onload = () => { window.setTimeout(window.close, 10000) }" in output
+
+
+@mark.parametrize(
+    "req, method, scheme, path",
+    [
+        (b"GET / HTTP/1.1\r\n", "GET", "", "/"),
+        (b"GET /foo HTTP/1.1\r\n", "GET", "", "/foo"),
+        (b"GET /foo/bar HTTP/1.1\r\n", "GET", "", "/foo/bar"),
+        (b"GET http://foo/ HTTP/1.1\r\n", "GET", "http", "/"),
+        (b"GET http://foo/bar HTTP/1.1\r\n", "GET", "http", "/bar"),
+    ],
+)
+def test_response_01(req, method, scheme, path):
+    """test Request.parse() success"""
+    request = Request.parse(req)
+    assert request.method == method
+    assert request.url.path == path
+    assert request.url.scheme == scheme
+
+
+@mark.parametrize(
+    "req",
+    [
+        b"a",
+        b"GET http://[test/ HTTP/1.1",
+        b"GET  HTTP/1.1",
+        b"GET a a a a a HTTP/1.1",
+    ],
+)
+def test_response_02(req):
+    """test Request.parse() failures"""
+    assert Request.parse(req) is None
